% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ASSISTDesigns.R
\docType{class}
\name{ASSISTDesign}
\alias{ASSISTDesign}
\title{A class to encapsulate the adaptive clinical trial design of Lai, Lavori and Liao}
\format{An \code{\link{R6Class}} generator object}
\usage{
ASSISTDesign
}
\description{
\code{ASSISTDesign} objects are used to design, simulate and analyze
adaptive group sequential clinical trial with three stages.
}
\section{Methods}{


\describe{
  \item{\code{new(designParameters, trialParameters, generateData)}}{Create a new
        instance object using the parameters specified}
  \item{\code{getDesignParameters}, \code{getTrialParameters}, \code{getBoundaries}}{Accessor
        methods for (obvious) object fields}
  \item{\code{print()}}{Print the object in a human readable form}
  \item{\code{computeCriticalValues()}}{Compute the critical boundary values \eqn{\tilde{b}},
        \eqn{b} and \eqn{c} for futility, efficacy and final efficacy decisions; saved in field
        \code{boundaries}}
  \item{\code{explore(numberOfSimulations, rngSeed,
              trueParameters, showProgress)}}{Explore the
        design using the specified number of simulations (default 5000) and random number seed (default 12345).
        The argument \code{trueParameters} is by default the same
        as \code{designParameters} as would be the case for a Type I error calculation. If changed, would yield power.
        Show progress if so desired (default \code{TRUE}). Returns a data frame of results}
  \item{\code{analyze(trialHistory)}}{Analyze
        the design given the \code{trialHistory} which is the result of a call to \code{explore} to
        simulate the design. Return a list of summary quantities}
  \item{\code{summary(analysis)}}{Print the operating characteristics of the design, using the analysis
        result from the \code{analyze} call}
}
}
\examples{
\dontrun{
data(LLL.SETTINGS)
prevalence <- LLL.SETTINGS$prevalences$table1
scenario <- LLL.SETTINGS$scenarios$S0
designParameters <- list(prevalence = prevalence,
                       mean = scenario$mean,
                       sd = scenario$sd)
designA <- ASSISTDesign$new(trialParameters = LLL.SETTINGS$trialParameters,
                            designParameters = designParameters)
print(designA)
## A realistic design uses 5000 simulations or more!
result <- designA$explore(showProgress = interactive())
analysis <- designA$analyze(result)
designA$summary(analysis)
}
## For full examples, try:
## browseURL(system.file("full_doc/ASSISTant.html", package="ASSISTant"))

}
\references{
Adaptive Choice of Patient Subgroup for Comparing Two Treatments
by Tze Leung Lai and Philip W. Lavori and Olivia Yueh-Wen Liao. Contemporary Clinical Trials,
Vol. 39, No. 2, pp 191-200 (2014). \url{http://www.sciencedirect.com/science/article/pii/S1551714414001311}.
}
\seealso{
\code{LLL.SETTINGS} for an explanation of trial parameters
}
\keyword{datasets}

